## pdf-tables
pdf-tables extracts tables from pdfs, whether normal or image-based. It uses pdfplumber (https://github.com/jsvine/pdfplumber) for pdf parsing, and tesserocr for ocr on image-based pdfs.

## Installation
```pip3 install pdf-tables```

## Usage
pdftables -f input.pdf

## Help
Let me know if you have issues!